==> EasyThread-0.4.0-sources.jar: com/lzh/easythread/CallableWrapper.java <==
/*
 * Copyright (C) 2017 Haoge
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.lzh.easythread;

import java.util.concurrent.Callable;

final class CallableWrapper<T> implements Callable<T> {
    private String name;
    private Callback callback;
    private Callable<T> proxy;
    private long delay;

    CallableWrapper(String name, long delay, Callback callback, Callable<T> proxy) {
        this.name = name;
        this.callback = callback;
        this.proxy = proxy;
        this.delay = delay;
    }

    @Override
    public T call() throws Exception {
        Tools.resetThread(Thread.currentThread(),name,callback);
        Tools.sleepThread(delay);
        if (callback != null) {
            callback.onStart(Thread.currentThread());
        }

        // avoid NullPointException
        T t = proxy == null ? null : proxy.call();
        if (callback != null)  {
            callback.onCompleted(Thread.currentThread());
        }
        return t;
    }
}

==> EasyThread-0.5.0-sources.jar: com/lzh/easythread/CallableWrapper.java <==
/*
 * Copyright (C) 2017 Haoge
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.lzh.easythread;

import java.util.concurrent.Callable;

final class CallableWrapper<T> implements Callable<T> {
    private String name;
    private Callback callback;
    private Callable<T> proxy;
    private long delay;

    CallableWrapper(Configs configs, Callable<T> proxy) {
        this.name = configs.name;
        this.delay = configs.delay;
        this.proxy = proxy;
        this.callback = new CallbackDelegate(configs.callback, configs.deliver, configs.asyncCallback);
    }

    @Override
    public T call() throws Exception {
        Tools.resetThread(Thread.currentThread(),name,callback);
        Tools.sleepThread(delay);
        if (callback != null) {
            callback.onStart(name);
        }

        // avoid NullPointException
        T t = proxy == null ? null : proxy.call();
        if (callback != null)  {
            callback.onCompleted(name);
        }
        return t;
    }
}
